<?php

namespace App\Notifications;

use App\Models\Client;
use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;
use Illuminate\Support\HtmlString;

class LeadAdded extends Notification implements ShouldQueue {
    use Queueable;

    public $nid, $nType;
    public $notification_to;

    /**
     * Create a new notification instance.
     */
    public function __construct($nid, $notification_to) {
        $this->nid = $nid;
        $this->nType = Client::class;
        $this->notification_to = $notification_to;
    }

    /**
     * Get the notification's delivery channels.
     *
     * @return array<int, string>
     */
    public function via(object $notifiable): array {
        return ['mail', 'database'];
    }

    /**
     * Get the mail representation of the notification.
     */
    public function toMail(object $notifiable): MailMessage {
        return (new MailMessage)
            ->subject("New Lead Received from DigiSplix")
            ->greeting("Hi " . $notifiable->name . ",")
            ->line(new HtmlString("DigiSplix has given you a New Lead. To get started on this lead, please log in to the Partner's dashboard."))
            ->action('Login', config('custom.partner_subdomain'));;
    }

    /**
     * Get the database representation of the notification.
     *
     * @return array<string, mixed>
     */
    public function toDatabase(object $notifiable): array {
        return [
            'message' => "New Lead Received",
            "link" => route('partner.leads.index')
        ];
    }
}
